<html>
<head>
<title>newPilotPerson: Address Tab</title>
<style type="text/css">
<!--
h1 {  font-family: Arial, Helvetica, sans-serif; color: #006666}
body {  font-family: Arial, Helvetica, sans-serif}
-->
</style>
</head>
<body bgcolor="#ffffff">
<form name="Person">
  <table>
    <tr> 
      <td align="center" valign="top" colspan="2"> 
        <p><img src="../images/ca_logo.gif" width="200" height="45"/></p>
        <table border="0" cellpadding="0" cellspacing="0" width="300">
          <tr valign="top"> 
            <td><a href="Main.html"><img name="main" src="../images/main.gif" width="100" height="20" border="0"/></a></td>
            <td><img name="address" src="../images/address2.gif" width="100" height="20" border="0"/></td>
            <td><a href="other.html"><img name="other" src="../images/other.gif" width="100" height="20" border="0"/></a></td>
          </tr>
        </table>
        <h1>newPilotPerson</h1>
      </td>
    </tr>
    <tr> 
      <td align="right" valign="top"  width="200">Home Postal Address:</td>
      <td width="230"> 
        <textarea name="homePostalAddress" rows="4"></textarea>
      </td>
    </tr>
    <tr> 
      <td width="200"></td>
      <td width="230"> 
        <input type="submit" name="Submit" value="Submit"/>
        &#160; 
        <input type="reset"/>
      </td>
    </tr>
  </table>
</form>
</body>
</html>

