<html xmlns:dxtemplate="http:www.opendirectory.ca.com/dxtemplate">
<head>
<title>Simple view: displays all attributes.</title>
</head>
<body bgcolor="#F0F8FF">

<center><img src="JXBanner.gif" width="454" height="69" border="1"/></center>

<h2><font face="arial">Simple view: displaying all attributes...</font></h2>
<dxtemplate:get-all-attributes style="list"/>

</body>
</html>
